@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,7 +22,7 @@
 #define KDEAPPLICATIONTREELISTWIDGET_H
 
 #include <QTreeWidget>
-#include "kdebugsettingsdialog.h"
+#include "loggingcategory.h"
 class CategoryTypeComboBox;
 class KDEApplicationTreeListWidgetItem : public QTreeWidgetItem
 {
@@ -37,9 +37,9 @@ public:
 
     QString logName() const;
     void setLogName(const QString &category);
-    void setType(const QString &type);
+    void setType(LoggingCategory::LoggingType type);
 
-    Category rule();
+    LoggingCategory rule();
 private:
     QString mCategory;
     CategoryTypeComboBox *mCategoryTypeCombobox;
@@ -55,11 +55,11 @@ public:
     void deSelectAllDebugCategories();
     void selectAllDebugCategories();
 
-    void fillList(const Category::List &list);
-    void insertCategories(const Category::List &list);
-    Category::List rules();
+    void fillList(const LoggingCategory::List &list);
+    void insertCategories(const LoggingCategory::List &list);
+    LoggingCategory::List rules();
 private:
-    void addListItems(const Category::List &list, bool clearList);
+    void addListItems(const LoggingCategory::List &list, bool clearList);
 };
 
 #endif // KDEAPPLICATIONTREELISTWIDGET_H
