@@ -22,10 +22,59 @@
 #include "kdebugsettings_debug.h"
 #include <QFile>
 
+RenameCategory KDebugSettingsUtil::parseRenameCategory(QString line)
+{
+    RenameCategory category;
+    int pos = line.indexOf(QLatin1Char('#'));
+    if (pos != -1) {
+        line.truncate(pos);
+        line = line.simplified();
+    }
+
+    if (line.isEmpty()) {
+        return category;
+    }
+    line = line.simplified();
+    const int space = line.indexOf(QLatin1Char(' '));
+    if (space == -1) {
+        qCWarning(KDEBUGSETTINGS_LOG) << "No space:" << line << endl;
+        return category;
+    }
+
+    const QString originalName = line.left(space);
+
+    const QString newName = line.mid(space).simplified();
+    category.originalName = originalName;
+    category.newName = newName;
+    return category;
+}
+
+RenameCategory::List KDebugSettingsUtil::readRenameCategories(const QString &filename)
+{
+    RenameCategory::List insertCategories;
+
+    QFile file(filename);
+    if (!file.open(QIODevice::ReadOnly)) {
+        qCWarning(KDEBUGSETTINGS_LOG) << "Couldn't open" << filename;
+    } else {
+        QString data;
+        QTextStream ts(&file);
+        ts.setCodec("ISO-8859-1");
+        while (!ts.atEnd()) {
+            data = ts.readLine().simplified();
+            const RenameCategory category = parseRenameCategory(data);
+            if (category.isValid()) {
+                insertCategories.append(category);
+            }
+        }
+    }
+    return insertCategories;
+}
+
 KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line)
 {
     KdeLoggingCategory category;
-    int pos = line.indexOf(QStringLiteral("#"));
+    int pos = line.indexOf(QLatin1Char('#'));
     if (pos != -1) {
         line.truncate(pos);
         line = line.simplified();
